@@ -10,9 +10,9 @@ It is not integral to the conversion, it's just a utility.
 
 __author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
 __email__ = "matteo.ferla@gmail.com"
-__date__ = "25 June 2020 A.D."
+__date__ = "10 July 2020 A.D."
 __license__ = "MIT"
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 __citation__ = "None."
 
 ########################################################################################################################
